@@ -3,13 +3,14 @@
  * address_book_import.php
  *
  * Copyright (c) 1999-2006 The SquirrelMail Project Team
+ * Copyright (c) 2007 Tomas Kuliavas <tokul@users.sourceforge.net>
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * Import csv files for address book
  * This takes a comma delimited file uploaded from addressbook.php
  * and allows the user to rearrange the field order to better
  * fit the address book. A subset of data is manipulated to save time.
- * @version $Id: address_book_import.php,v 1.25 2006/07/29 07:36:27 tokul Exp $
+ * @version $Id: address_book_import.php,v 1.26 2007/06/09 08:38:42 tokul Exp $
  * @package sm-plugins
  * @subpackage abook_import_export
  */
@@ -103,6 +104,10 @@ if (! sqGetGlobalVar('finish',$finish,SQ_POST)) {
             case 7:
                 $upload_error = _("Failed to write file to disk.");
                 break;
+            case 8:
+                // File upload stopped by extension. 'security library' is more user friendly.
+                $upload_error = _("File upload stopped by security library.");
+                break;
             default:
                 $upload_error = _("Unknown upload error.");
                 break;
@@ -133,6 +138,18 @@ if (! sqGetGlobalVar('finish',$finish,SQ_POST)) {
 
     // find unused file name in attachment directory.
     $temp_file = md5($smusercsv['tmp_name']);
+
+    // handle misconfigured $attachment_dir
+    if (preg_match('/^[a-z]\:\\\\/i',$attachment_dir)) {
+        // windows full path x:\something. relative path issues are ignored, because they will
+        // require mods in all SquirrelMail scripts.
+        if (substr($attachment_dir,-1,1)!='\\') {
+            $attachment_dir.= '\\';
+        }
+    } elseif (substr($attachment_dir,-1,1)!='/') {
+        $attachment_dir.= '/';
+    }
+
     while (file_exists($attachment_dir . $temp_file)) {
         // calculate new md5sum until we find place to store data
         $temp_file = md5($temp_file);
@@ -212,6 +229,8 @@ if (! sqGetGlobalVar('finish',$finish,SQ_POST)) {
             }
         }
 
+        // close file handle
+        fclose($csvfile);
         // remove uploaded file
         unlink($attachment_dir . $temp_file);
 
